@@ -201,9 +201,8 @@ def _py_to_couch_translate(key, val):
             return {key: val}
         elif val is None:
             return {key: None}
-        else:
-            arg_converter = TYPE_CONVERTERS.get(type(val))
-            return {key: arg_converter(val)}
+        arg_converter = TYPE_CONVERTERS.get(type(val))
+        return {key: arg_converter(val)}
     except Exception as ex:
         raise CloudantArgumentError(136, key, ex)
 
@@ -238,11 +237,11 @@ def get_docs(r_session, url, encoder=None, headers=None, **params):
     """
     keys_list = params.pop('keys', None)
     keys = None
-    if keys_list:
+    if keys_list is not None:
         keys = json.dumps({'keys': keys_list}, cls=encoder)
     f_params = python_to_couch(params)
     resp = None
-    if keys:
+    if keys is not None:
         # If we're using POST we are sending JSON so add the header
         if headers is None:
             headers = {}
@@ -284,6 +283,8 @@ class _Code(str):
     codifying map and reduce Javascript content.
     """
     def __new__(cls, code):
+        if type(code).__name__ == 'unicode':
+            return str.__new__(cls, code.encode('utf8'))
         return str.__new__(cls, code)
 
 class InfiniteSession(Session):
@@ -299,7 +300,7 @@ class InfiniteSession(Session):
         self._server_url = server_url
         self._timeout = kwargs.get('timeout', None)
 
-    def request(self, method, url, **kwargs):
+    def request(self, method, url, **kwargs):  # pylint: disable=W0221
         """
         Overrides ``requests.Session.request`` to perform a POST to the
         _session endpoint to renew Session cookie authentication settings and
@@ -338,7 +339,7 @@ class ClientSession(Session):
         self._server_url = server_url
         self._timeout = kwargs.get('timeout', None)
 
-    def request(self, method, url, **kwargs):
+    def request(self, method, url, **kwargs):  # pylint: disable=W0221
         """
         Overrides ``requests.Session.request`` to set the timeout.
         """
