@@ -157,10 +157,15 @@ class CouchDatabase(dict):
             doc = DesignDocument(self, docid)
         else:
             doc = Document(self, docid)
-        if throw_on_exists and doc.exists():
-            raise CloudantDatabaseException(409, docid)
         doc.update(data)
-        doc.create()
+        try:
+            doc.create()
+        except HTTPError as error:
+            if error.response.status_code == 409:
+                if throw_on_exists:
+                    raise CloudantDatabaseException(409, docid)
+            else:
+                raise
         super(CouchDatabase, self).__setitem__(doc['_id'], doc)
         return doc
 
@@ -326,18 +331,22 @@ class CouchDatabase(dict):
             return view(**kwargs)
         elif kwargs:
             return Result(view, **kwargs)
-        else:
-            return view.result
 
-    def create(self):
+        return view.result
+
+    def create(self, throw_on_exists=False):
         """
         Creates a database defined by the current database object, if it
         does not already exist and raises a CloudantException if the operation
         fails.  If the database already exists then this method call is a no-op.
 
+        :param bool throw_on_exists: Boolean flag dictating whether or
+            not to throw a CloudantDatabaseException when attempting to
+            create a database that already exists.
+
         :returns: The database object
         """
-        if self.exists():
+        if not throw_on_exists and self.exists():
             return self
 
         resp = self.r_session.put(self.database_url)
@@ -621,18 +630,20 @@ class CouchDatabase(dict):
         if not remote:
             super(CouchDatabase, self).__iter__()
         else:
-            next_startkey = '0'
+            # Use unicode Null U+0000 as the initial lower bound to ensure any
+            # document id could exist in the results set.
+            next_startkey = u'\u0000'
             while next_startkey is not None:
                 docs = self.all_docs(
-                    limit=self._fetch_limit + 1,  # Get one extra doc
-                                                  # to use as
-                                                  # next_startkey
+                    limit=self._fetch_limit,
                     include_docs=True,
                     startkey=next_startkey
                 ).get('rows', [])
 
-                if len(docs) > self._fetch_limit:
-                    next_startkey = docs.pop()['id']
+                if len(docs) >= self._fetch_limit:
+                    # Ensure the next document batch contains ids that sort
+                    # strictly higher than the previous document id fetched.
+                    next_startkey = docs[-1]['id'] + u'\u0000'
                 else:
                     # This is the last batch of docs, so we set
                     # ourselves up to break out of the while loop
@@ -758,7 +769,7 @@ class CouchDatabase(dict):
         """
         url = posixpath.join(self.database_url, '_revs_limit')
 
-        resp = self.r_session.put(url, data=json.dumps(limit, self.client.encoder))
+        resp = self.r_session.put(url, data=json.dumps(limit, cls=self.client.encoder))
         resp.raise_for_status()
 
         return resp.json()
@@ -1228,8 +1239,8 @@ class CloudantDatabase(CouchDatabase):
             return query(**kwargs)
         if kwargs:
             return QueryResult(query, **kwargs)
-        else:
-            return query.result
+
+        return query.result
 
     def get_search_result(self, ddoc_id, index_name, **query_params):
         """
