@@ -19,7 +19,7 @@ from ._2to3 import iteritems_, STRTYPE
 from ._common_util import QUERY_LANGUAGE, codify
 from .document import Document
 from .view import View, QueryIndexView
-from .error import CloudantArgumentError, CloudantException
+from .error import CloudantArgumentError, CloudantDesignDocumentException
 
 class DesignDocument(Document):
     """
@@ -282,12 +282,9 @@ class DesignDocument(Document):
         :param str reduce_func: Optional Javascript reduce function.
         """
         if self.get_view(view_name) is not None:
-            msg = "View {0} already exists in this design doc".format(view_name)
-            raise CloudantArgumentError(msg)
+            raise CloudantArgumentError(107, view_name)
         if self.get('language', None) == QUERY_LANGUAGE:
-            msg = ('Cannot add a MapReduce view to a '
-                   'design document for query indexes.')
-            raise CloudantException(msg)
+            raise CloudantDesignDocumentException(101)
 
         view = View(self, view_name, map_func, reduce_func, **kwargs)
         self.views.__setitem__(view_name, view)
@@ -302,9 +299,7 @@ class DesignDocument(Document):
         :param analyzer: Optional analyzer for this search index.
         """
         if self.get_index(index_name) is not None:
-            msg = ('An index with name {0} already exists in this design doc'
-                   .format(index_name))
-            raise CloudantArgumentError(msg)
+            raise CloudantArgumentError(108, index_name)
         if analyzer is not None:
             search = {'index': codify(search_func), 'analyzer': analyzer}
         else:
@@ -321,9 +316,7 @@ class DesignDocument(Document):
         :param str list_func: Javascript list function.
         """
         if self.get_list_function(list_name) is not None:
-            msg = ('A list with name {0} already exists in this design doc'
-                   .format(list_name))
-            raise CloudantArgumentError(msg)
+            raise CloudantArgumentError(109, list_name)
 
         self.lists.__setitem__(list_name, codify(list_func))
 
@@ -336,9 +329,7 @@ class DesignDocument(Document):
         :param show_func: Javascript show function.
         """
         if self.get_show_function(show_name) is not None:
-            msg = ('A show function with name {0} already exists in this design doc'
-                   .format(show_name))
-            raise CloudantArgumentError(msg)
+            raise CloudantArgumentError(110, show_name)
 
         self.shows.__setitem__(show_name, show_func)
 
@@ -358,11 +349,9 @@ class DesignDocument(Document):
         """
         view = self.get_view(view_name)
         if view is None:
-            msg = "View {0} does not exist in this design doc".format(view_name)
-            raise CloudantArgumentError(msg)
+            raise CloudantArgumentError(111, view_name)
         if isinstance(view, QueryIndexView):
-            msg = 'Cannot update a query index view using this method.'
-            raise CloudantException(msg)
+            raise CloudantDesignDocumentException(102)
 
         view = View(self, view_name, map_func, reduce_func, **kwargs)
         self.views.__setitem__(view_name, view)
@@ -378,9 +367,7 @@ class DesignDocument(Document):
         """
         search = self.get_index(index_name)
         if search is None:
-            msg = ('An index with name {0} does not exist in this design doc'
-                   .format(index_name))
-            raise CloudantArgumentError(msg)
+            raise CloudantArgumentError(112, index_name)
         if analyzer is not None:
             search = {'index': codify(search_func), 'analyzer': analyzer}
         else:
@@ -397,9 +384,7 @@ class DesignDocument(Document):
         :param str list_func: Javascript list function.
         """
         if self.get_list_function(list_name) is None:
-            msg = ('A list with name {0} does not exist in this design doc'
-                   .format(list_name))
-            raise CloudantArgumentError(msg)
+            raise CloudantArgumentError(113, list_name)
 
         self.lists.__setitem__(list_name, codify(list_func))
 
@@ -412,9 +397,7 @@ class DesignDocument(Document):
         :param show_func: Javascript show function.
         """
         if self.get_show_function(show_name) is None:
-            msg = ('A show function with name {0} does not exist in this design doc'
-                   .format(show_name))
-            raise CloudantArgumentError(msg)
+            raise CloudantArgumentError(114, show_name)
 
         self.shows.__setitem__(show_name, show_func)
 
@@ -432,8 +415,7 @@ class DesignDocument(Document):
         if view is None:
             return
         if isinstance(view, QueryIndexView):
-            msg = 'Cannot delete a query index view using this method.'
-            raise CloudantException(msg)
+            raise CloudantDesignDocumentException(103)
 
         self.views.__delitem__(view_name)
 
@@ -517,34 +499,22 @@ class DesignDocument(Document):
             if self.get('language', None) != QUERY_LANGUAGE:
                 for view_name, view in self.iterviews():
                     if isinstance(view, QueryIndexView):
-                        msg = 'View {0} must be of type View.'.format(view_name)
-                        raise CloudantException(msg)
+                        raise CloudantDesignDocumentException(104, view_name)
             else:
                 for view_name, view in self.iterviews():
                     if not isinstance(view, QueryIndexView):
-                        msg = (
-                            'View {0} must be of type QueryIndexView.'
-                        ).format(view_name)
-                        raise CloudantException(msg)
+                        raise CloudantDesignDocumentException(105, view_name)
 
         if self.indexes:
             if self.get('language', None) != QUERY_LANGUAGE:
                 for index_name, search in self.iterindexes():
                     # Check the instance of the javascript search function
                     if not isinstance(search['index'], STRTYPE):
-                        msg = (
-                            'Function for search index {0} must '
-                            'be of type string.'
-                        ).format(index_name)
-                        raise CloudantException(msg)
+                        raise CloudantDesignDocumentException(106, index_name)
             else:
                 for index_name, index in self.iterindexes():
                     if not isinstance(index['index'], dict):
-                        msg = (
-                            'Definition for query text index {0} must '
-                            'be of type dict.'
-                        ).format(index_name)
-                        raise CloudantException(msg)
+                        raise CloudantDesignDocumentException(107, index_name)
 
         for prop in self._nested_object_names:
             if not getattr(self, prop):
@@ -715,6 +685,7 @@ class DesignDocument(Document):
         """
         ddoc_info = self.r_session.get(
             '/'.join([self.document_url, '_info']))
+        ddoc_info.raise_for_status()
         return ddoc_info.json()
 
     def search_info(self, search_index):
@@ -726,4 +697,5 @@ class DesignDocument(Document):
         """
         ddoc_search_info = self.r_session.get(
             '/'.join([self.document_url, '_search_info', search_index]))
+        ddoc_search_info.raise_for_status()
         return ddoc_search_info.json()
